# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/build_url.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bqwak/builds/build_url.proto\x12\x18qwak.builds.orchestrator\"\xe7\x01\n\x18\x42uildVersioningUrlParams\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x04 \x01(\t\x12\x43\n\x08tag_type\x18\x05 \x01(\x0e\x32\x31.qwak.builds.orchestrator.BuildVersioningTagsType\x12$\n\x1ause_cloud_provider_storage\x18\x06 \x01(\x08H\x00\x42\x17\n\x15\x63loud_provider_option\"\xb5\x01\n\x13\x42uildVersioningTags\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x10\n\x04tags\x18\x03 \x03(\tB\x02\x18\x01\x12P\n\x0ftags_definition\x18\x04 \x03(\x0b\x32\x37.qwak.builds.orchestrator.BuildVersioningTagsDefinition\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\"n\n\x1d\x42uildVersioningTagsDefinition\x12\x0c\n\x04tags\x18\x01 \x03(\t\x12?\n\x04type\x18\x02 \x01(\x0e\x32\x31.qwak.builds.orchestrator.BuildVersioningTagsType\"\xf8\x01\n\x1d\x42uildVersioningTagsProperties\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\x12\x11\n\tfile_size\x18\x03 \x01(\x03\x12\x43\n\x08tag_type\x18\x04 \x01(\x0e\x32\x31.qwak.builds.orchestrator.BuildVersioningTagsType\x12\x44\n\x15\x65xternal_download_url\x18\x05 \x01(\x0b\x32%.qwak.builds.orchestrator.ExternalUrl\x12\x16\n\x0eui_direct_link\x18\x06 \x01(\t\"5\n\x0b\x45xternalUrl\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x19\n\x11original_hostname\x18\x02 \x01(\t\"Z\n\x15\x42uildArtifactPathSpec\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x10\n\x08key_path\x18\x04 \x01(\t\"\x0e\n\x0c\x44\x61taArtifact\"\x0e\n\x0c\x43odeArtifact\"\x0e\n\x0c\x46ileArtifact\"\xf6\x01\n\rBuildArtifact\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\rdata_artifact\x18\x02 \x01(\x0b\x32&.qwak.builds.orchestrator.DataArtifactH\x00\x12?\n\rcode_artifact\x18\x03 \x01(\x0b\x32&.qwak.builds.orchestrator.CodeArtifactH\x00\x12?\n\rfile_artifact\x18\x04 \x01(\x0b\x32&.qwak.builds.orchestrator.FileArtifactH\x00\x12\x0c\n\x04path\x18\x05 \x01(\tB\x06\n\x04type*h\n\x17\x42uildVersioningTagsType\x12\x14\n\x10INVALID_TAG_TYPE\x10\x00\x12\x11\n\rDATA_TAG_TYPE\x10\x01\x12\x11\n\rFILE_TAG_TYPE\x10\x02\x12\x11\n\rCODE_TAG_TYPE\x10\x03\x42\'\n#com.qwak.ai.builds.orchestrator.apiP\x01\x62\x06proto3')

_BUILDVERSIONINGTAGSTYPE = DESCRIPTOR.enum_types_by_name['BuildVersioningTagsType']
BuildVersioningTagsType = enum_type_wrapper.EnumTypeWrapper(_BUILDVERSIONINGTAGSTYPE)
INVALID_TAG_TYPE = 0
DATA_TAG_TYPE = 1
FILE_TAG_TYPE = 2
CODE_TAG_TYPE = 3


_BUILDVERSIONINGURLPARAMS = DESCRIPTOR.message_types_by_name['BuildVersioningUrlParams']
_BUILDVERSIONINGTAGS = DESCRIPTOR.message_types_by_name['BuildVersioningTags']
_BUILDVERSIONINGTAGSDEFINITION = DESCRIPTOR.message_types_by_name['BuildVersioningTagsDefinition']
_BUILDVERSIONINGTAGSPROPERTIES = DESCRIPTOR.message_types_by_name['BuildVersioningTagsProperties']
_EXTERNALURL = DESCRIPTOR.message_types_by_name['ExternalUrl']
_BUILDARTIFACTPATHSPEC = DESCRIPTOR.message_types_by_name['BuildArtifactPathSpec']
_DATAARTIFACT = DESCRIPTOR.message_types_by_name['DataArtifact']
_CODEARTIFACT = DESCRIPTOR.message_types_by_name['CodeArtifact']
_FILEARTIFACT = DESCRIPTOR.message_types_by_name['FileArtifact']
_BUILDARTIFACT = DESCRIPTOR.message_types_by_name['BuildArtifact']
BuildVersioningUrlParams = _reflection.GeneratedProtocolMessageType('BuildVersioningUrlParams', (_message.Message,), {
  'DESCRIPTOR' : _BUILDVERSIONINGURLPARAMS,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildVersioningUrlParams)
  })
_sym_db.RegisterMessage(BuildVersioningUrlParams)

BuildVersioningTags = _reflection.GeneratedProtocolMessageType('BuildVersioningTags', (_message.Message,), {
  'DESCRIPTOR' : _BUILDVERSIONINGTAGS,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildVersioningTags)
  })
_sym_db.RegisterMessage(BuildVersioningTags)

BuildVersioningTagsDefinition = _reflection.GeneratedProtocolMessageType('BuildVersioningTagsDefinition', (_message.Message,), {
  'DESCRIPTOR' : _BUILDVERSIONINGTAGSDEFINITION,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildVersioningTagsDefinition)
  })
_sym_db.RegisterMessage(BuildVersioningTagsDefinition)

BuildVersioningTagsProperties = _reflection.GeneratedProtocolMessageType('BuildVersioningTagsProperties', (_message.Message,), {
  'DESCRIPTOR' : _BUILDVERSIONINGTAGSPROPERTIES,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildVersioningTagsProperties)
  })
_sym_db.RegisterMessage(BuildVersioningTagsProperties)

ExternalUrl = _reflection.GeneratedProtocolMessageType('ExternalUrl', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALURL,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.ExternalUrl)
  })
_sym_db.RegisterMessage(ExternalUrl)

BuildArtifactPathSpec = _reflection.GeneratedProtocolMessageType('BuildArtifactPathSpec', (_message.Message,), {
  'DESCRIPTOR' : _BUILDARTIFACTPATHSPEC,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildArtifactPathSpec)
  })
_sym_db.RegisterMessage(BuildArtifactPathSpec)

DataArtifact = _reflection.GeneratedProtocolMessageType('DataArtifact', (_message.Message,), {
  'DESCRIPTOR' : _DATAARTIFACT,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.DataArtifact)
  })
_sym_db.RegisterMessage(DataArtifact)

CodeArtifact = _reflection.GeneratedProtocolMessageType('CodeArtifact', (_message.Message,), {
  'DESCRIPTOR' : _CODEARTIFACT,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CodeArtifact)
  })
_sym_db.RegisterMessage(CodeArtifact)

FileArtifact = _reflection.GeneratedProtocolMessageType('FileArtifact', (_message.Message,), {
  'DESCRIPTOR' : _FILEARTIFACT,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.FileArtifact)
  })
_sym_db.RegisterMessage(FileArtifact)

BuildArtifact = _reflection.GeneratedProtocolMessageType('BuildArtifact', (_message.Message,), {
  'DESCRIPTOR' : _BUILDARTIFACT,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildArtifact)
  })
_sym_db.RegisterMessage(BuildArtifact)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.builds.orchestrator.apiP\001'
  _BUILDVERSIONINGTAGS.fields_by_name['tags']._options = None
  _BUILDVERSIONINGTAGS.fields_by_name['tags']._serialized_options = b'\030\001'
  _BUILDVERSIONINGTAGSTYPE._serialized_start=1282
  _BUILDVERSIONINGTAGSTYPE._serialized_end=1386
  _BUILDVERSIONINGURLPARAMS._serialized_start=58
  _BUILDVERSIONINGURLPARAMS._serialized_end=289
  _BUILDVERSIONINGTAGS._serialized_start=292
  _BUILDVERSIONINGTAGS._serialized_end=473
  _BUILDVERSIONINGTAGSDEFINITION._serialized_start=475
  _BUILDVERSIONINGTAGSDEFINITION._serialized_end=585
  _BUILDVERSIONINGTAGSPROPERTIES._serialized_start=588
  _BUILDVERSIONINGTAGSPROPERTIES._serialized_end=836
  _EXTERNALURL._serialized_start=838
  _EXTERNALURL._serialized_end=891
  _BUILDARTIFACTPATHSPEC._serialized_start=893
  _BUILDARTIFACTPATHSPEC._serialized_end=983
  _DATAARTIFACT._serialized_start=985
  _DATAARTIFACT._serialized_end=999
  _CODEARTIFACT._serialized_start=1001
  _CODEARTIFACT._serialized_end=1015
  _FILEARTIFACT._serialized_start=1017
  _FILEARTIFACT._serialized_end=1031
  _BUILDARTIFACT._serialized_start=1034
  _BUILDARTIFACT._serialized_end=1280
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FeaturesetState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    featureset_name: builtins.str
    """TODO - FILL THIS WITH THE ACTUAL STATE REPRESENTATION
    we need to find an elegant way of representing a state that is not just an enum value -
    for example, in streaming aggr, if compaction failed but row-level is running.
    another example is batchV1 where batch ingestion worked but realtime is failing
    """
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id", "featureset_name", b"featureset_name"]) -> None: ...

global___FeaturesetState = FeaturesetState



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/model_analytics_storage_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.external import kafka_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_external_dot_kafka__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQqwak/administration/runtime_configuration/v0/model_analytics_storage_config.proto\x12Kqwak.administration.runtime_configuration.v0.model_analytics_storage_config\x1aHqwak/administration/runtime_configuration/v0/external/kafka_config.proto\"\x9d\x01\n\"ModelAnalyticsStorageConfiguration\x12g\n\x05kafka\x18\x01 \x01(\x0b\x32V.qwak.administration.runtime_configuration.v0.external.kafka_config.KafkaConfigurationH\x00\x42\x0e\n\x0cstorage_typeB\xeb\x01\nDcom.jfrog.ml.runtime_configuration.v0.model_analytics_storage_configP\x01Z\xa0\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0b\x06proto3')



_MODELANALYTICSSTORAGECONFIGURATION = DESCRIPTOR.message_types_by_name['ModelAnalyticsStorageConfiguration']
ModelAnalyticsStorageConfiguration = _reflection.GeneratedProtocolMessageType('ModelAnalyticsStorageConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _MODELANALYTICSSTORAGECONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.model_analytics_storage_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.model_analytics_storage_config.ModelAnalyticsStorageConfiguration)
  })
_sym_db.RegisterMessage(ModelAnalyticsStorageConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nDcom.jfrog.ml.runtime_configuration.v0.model_analytics_storage_configP\001Z\240\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0'
  _MODELANALYTICSSTORAGECONFIGURATION._serialized_start=237
  _MODELANALYTICSSTORAGECONFIGURATION._serialized_end=394
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.audience.v1.audience_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    @property
    def audience(self) -> qwak.audience.v1.audience_pb2.Audience: ...
    def __init__(
        self,
        *,
        audience: qwak.audience.v1.audience_pb2.Audience | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> None: ...

global___CreateAudienceRequest = CreateAudienceRequest

class CreateAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_ID_FIELD_NUMBER: builtins.int
    audience_id: builtins.str
    def __init__(
        self,
        *,
        audience_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_id", b"audience_id"]) -> None: ...

global___CreateAudienceResponse = CreateAudienceResponse

class UpdateAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AUDIENCE_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def audience(self) -> qwak.audience.v1.audience_pb2.Audience: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        audience: qwak.audience.v1.audience_pb2.Audience | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "id", b"id"]) -> None: ...

global___UpdateAudienceRequest = UpdateAudienceRequest

class UpdateAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateAudienceResponse = UpdateAudienceResponse

class GetAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_ID_FIELD_NUMBER: builtins.int
    audience_id: builtins.str
    def __init__(
        self,
        *,
        audience_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_id", b"audience_id"]) -> None: ...

global___GetAudienceRequest = GetAudienceRequest

class GetAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    @property
    def audience(self) -> qwak.audience.v1.audience_pb2.Audience: ...
    def __init__(
        self,
        *,
        audience: qwak.audience.v1.audience_pb2.Audience | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> None: ...

global___GetAudienceResponse = GetAudienceResponse

class ListAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAudienceRequest = ListAudienceRequest

class ListAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def audience_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.audience.v1.audience_pb2.AudienceEntry]: ...
    def __init__(
        self,
        *,
        audience_entries: collections.abc.Iterable[qwak.audience.v1.audience_pb2.AudienceEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_entries", b"audience_entries"]) -> None: ...

global___ListAudienceResponse = ListAudienceResponse

class DeleteAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_ID_FIELD_NUMBER: builtins.int
    audience_id: builtins.str
    def __init__(
        self,
        *,
        audience_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_id", b"audience_id"]) -> None: ...

global___DeleteAudienceRequest = DeleteAudienceRequest

class DeleteAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteAudienceResponse = DeleteAudienceResponse

class SyncAudiencesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___SyncAudiencesRequest = SyncAudiencesRequest

class SyncAudiencesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SyncAudiencesResponse = SyncAudiencesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/prompt/v1/prompt/prompt.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.model_descriptor import open_ai_descriptor_pb2 as qwak_dot_model__descriptor_dot_open__ai__descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"qwak/prompt/v1/prompt/prompt.proto\x12\x15qwak.prompt.v1.prompt\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.qwak/model_descriptor/open_ai_descriptor.proto\"\xdb\x01\n\x06Prompt\x12\x0c\n\x04name\x18\x01 \x01(\t\x12R\n\x1a\x64\x65\x66\x61ult_version_definition\x18\x02 \x01(\x0b\x32..qwak.prompt.v1.prompt.PromptVersionDefinition\x12\x37\n\x08metadata\x18\x03 \x01(\x0b\x32%.qwak.prompt.v1.prompt.PromptMetadata\x12\x36\n\x0bprompt_spec\x18\x04 \x01(\x0b\x32!.qwak.prompt.v1.prompt.PromptSpec\"w\n\rPromptVersion\x12\x13\n\x0bprompt_name\x18\x01 \x01(\t\x12Q\n\x19prompt_version_definition\x18\x02 \x01(\x0b\x32..qwak.prompt.v1.prompt.PromptVersionDefinition\"\xb9\x01\n\x17PromptVersionDefinition\x12\x16\n\x0eversion_number\x18\x01 \x01(\x05\x12>\n\x0cversion_spec\x18\x02 \x01(\x0b\x32(.qwak.prompt.v1.prompt.PromptVersionSpec\x12\x46\n\x10version_metadata\x18\x03 \x01(\x0b\x32,.qwak.prompt.v1.prompt.PromptVersionMetadata\"^\n\x0bPromptBrief\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x0eversion_briefs\x18\x02 \x03(\x0b\x32).qwak.prompt.v1.prompt.PromptVersionBrief\"\x98\x01\n\x12PromptVersionBrief\x12\x16\n\x0eversion_number\x18\x01 \x01(\x05\x12I\n\x14model_provider_brief\x18\x02 \x01(\x0b\x32).qwak.prompt.v1.prompt.ModelProviderBriefH\x00\x42\x1f\n\x1doptional_model_provider_brief\"8\n\x12ModelProviderBrief\x12\"\n\x1amodel_provider_case_number\x18\x01 \x01(\x05\"!\n\nPromptSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\"\xcf\x01\n\x11PromptVersionSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12>\n\x0fprompt_template\x18\x02 \x01(\x0b\x32%.qwak.prompt.v1.prompt.PromptTemplate\x12H\n\x10model_descriptor\x18\x03 \x01(\x0b\x32,.qwak.prompt.v1.prompt.PromptModelDescriptorH\x00\x42\x1b\n\x19optional_model_descriptor\"c\n\x0ePromptTemplate\x12I\n\x14\x63hat_prompt_template\x18\x01 \x01(\x0b\x32).qwak.prompt.v1.prompt.ChatPromptTemplateH\x00\x42\x06\n\x04type\"O\n\x12\x43hatPromptTemplate\x12\x39\n\rchat_messages\x18\x01 \x03(\x0b\x32\".qwak.prompt.v1.prompt.ChatMessage\"\x83\x01\n\x0b\x43hatMessage\x12\x36\n\x04role\x18\x01 \x01(\x0b\x32(.qwak.prompt.v1.prompt.PromptMessageRole\x12<\n\x08template\x18\x02 \x01(\x0b\x32*.qwak.prompt.v1.prompt.ChatMessageTemplate\"[\n\x13\x43hatMessageTemplate\x12<\n\rtext_template\x18\x01 \x01(\x0b\x32#.qwak.prompt.v1.prompt.TextTemplateH\x00\x42\x06\n\x04type\" \n\x0cTextTemplate\x12\x10\n\x08template\x18\x01 \x01(\t\"\xe6\x01\n\x11PromptMessageRole\x12\x43\n\nhuman_role\x18\x01 \x01(\x0b\x32-.qwak.prompt.v1.prompt.HumanPromptMessageRoleH\x00\x12\x45\n\x0bsystem_role\x18\x02 \x01(\x0b\x32..qwak.prompt.v1.prompt.SystemPromptMessageRoleH\x00\x12=\n\x07\x61i_role\x18\x03 \x01(\x0b\x32*.qwak.prompt.v1.prompt.AIPromptMessageRoleH\x00\x42\x06\n\x04role\"\x18\n\x16HumanPromptMessageRole\"\x19\n\x17SystemPromptMessageRole\"\x15\n\x13\x41IPromptMessageRole\"r\n\x15PromptModelDescriptor\x12G\n\x10open_ai_provider\x18\x01 \x01(\x0b\x32+.qwak.prompt.v1.prompt.PromptOpenAIProviderH\x00\x42\x10\n\x0emodel_provider\"t\n\x14PromptOpenAIProvider\x12\\\n\x18open_ai_model_descriptor\x18\x01 \x01(\x0b\x32:.qwak.llmops.model_descriptor.openai.OpenAIModelDescriptor\"T\n\x0ePromptMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\"[\n\x15PromptVersionMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\tB$\n com.qwak.ai.prompt.api.v1.promptP\x01\x62\x06proto3')



_PROMPT = DESCRIPTOR.message_types_by_name['Prompt']
_PROMPTVERSION = DESCRIPTOR.message_types_by_name['PromptVersion']
_PROMPTVERSIONDEFINITION = DESCRIPTOR.message_types_by_name['PromptVersionDefinition']
_PROMPTBRIEF = DESCRIPTOR.message_types_by_name['PromptBrief']
_PROMPTVERSIONBRIEF = DESCRIPTOR.message_types_by_name['PromptVersionBrief']
_MODELPROVIDERBRIEF = DESCRIPTOR.message_types_by_name['ModelProviderBrief']
_PROMPTSPEC = DESCRIPTOR.message_types_by_name['PromptSpec']
_PROMPTVERSIONSPEC = DESCRIPTOR.message_types_by_name['PromptVersionSpec']
_PROMPTTEMPLATE = DESCRIPTOR.message_types_by_name['PromptTemplate']
_CHATPROMPTTEMPLATE = DESCRIPTOR.message_types_by_name['ChatPromptTemplate']
_CHATMESSAGE = DESCRIPTOR.message_types_by_name['ChatMessage']
_CHATMESSAGETEMPLATE = DESCRIPTOR.message_types_by_name['ChatMessageTemplate']
_TEXTTEMPLATE = DESCRIPTOR.message_types_by_name['TextTemplate']
_PROMPTMESSAGEROLE = DESCRIPTOR.message_types_by_name['PromptMessageRole']
_HUMANPROMPTMESSAGEROLE = DESCRIPTOR.message_types_by_name['HumanPromptMessageRole']
_SYSTEMPROMPTMESSAGEROLE = DESCRIPTOR.message_types_by_name['SystemPromptMessageRole']
_AIPROMPTMESSAGEROLE = DESCRIPTOR.message_types_by_name['AIPromptMessageRole']
_PROMPTMODELDESCRIPTOR = DESCRIPTOR.message_types_by_name['PromptModelDescriptor']
_PROMPTOPENAIPROVIDER = DESCRIPTOR.message_types_by_name['PromptOpenAIProvider']
_PROMPTMETADATA = DESCRIPTOR.message_types_by_name['PromptMetadata']
_PROMPTVERSIONMETADATA = DESCRIPTOR.message_types_by_name['PromptVersionMetadata']
Prompt = _reflection.GeneratedProtocolMessageType('Prompt', (_message.Message,), {
  'DESCRIPTOR' : _PROMPT,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.Prompt)
  })
_sym_db.RegisterMessage(Prompt)

PromptVersion = _reflection.GeneratedProtocolMessageType('PromptVersion', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTVERSION,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptVersion)
  })
_sym_db.RegisterMessage(PromptVersion)

PromptVersionDefinition = _reflection.GeneratedProtocolMessageType('PromptVersionDefinition', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTVERSIONDEFINITION,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptVersionDefinition)
  })
_sym_db.RegisterMessage(PromptVersionDefinition)

PromptBrief = _reflection.GeneratedProtocolMessageType('PromptBrief', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTBRIEF,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptBrief)
  })
_sym_db.RegisterMessage(PromptBrief)

PromptVersionBrief = _reflection.GeneratedProtocolMessageType('PromptVersionBrief', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTVERSIONBRIEF,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptVersionBrief)
  })
_sym_db.RegisterMessage(PromptVersionBrief)

ModelProviderBrief = _reflection.GeneratedProtocolMessageType('ModelProviderBrief', (_message.Message,), {
  'DESCRIPTOR' : _MODELPROVIDERBRIEF,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.ModelProviderBrief)
  })
_sym_db.RegisterMessage(ModelProviderBrief)

PromptSpec = _reflection.GeneratedProtocolMessageType('PromptSpec', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTSPEC,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptSpec)
  })
_sym_db.RegisterMessage(PromptSpec)

PromptVersionSpec = _reflection.GeneratedProtocolMessageType('PromptVersionSpec', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTVERSIONSPEC,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptVersionSpec)
  })
_sym_db.RegisterMessage(PromptVersionSpec)

PromptTemplate = _reflection.GeneratedProtocolMessageType('PromptTemplate', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTTEMPLATE,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptTemplate)
  })
_sym_db.RegisterMessage(PromptTemplate)

ChatPromptTemplate = _reflection.GeneratedProtocolMessageType('ChatPromptTemplate', (_message.Message,), {
  'DESCRIPTOR' : _CHATPROMPTTEMPLATE,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.ChatPromptTemplate)
  })
_sym_db.RegisterMessage(ChatPromptTemplate)

ChatMessage = _reflection.GeneratedProtocolMessageType('ChatMessage', (_message.Message,), {
  'DESCRIPTOR' : _CHATMESSAGE,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.ChatMessage)
  })
_sym_db.RegisterMessage(ChatMessage)

ChatMessageTemplate = _reflection.GeneratedProtocolMessageType('ChatMessageTemplate', (_message.Message,), {
  'DESCRIPTOR' : _CHATMESSAGETEMPLATE,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.ChatMessageTemplate)
  })
_sym_db.RegisterMessage(ChatMessageTemplate)

TextTemplate = _reflection.GeneratedProtocolMessageType('TextTemplate', (_message.Message,), {
  'DESCRIPTOR' : _TEXTTEMPLATE,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.TextTemplate)
  })
_sym_db.RegisterMessage(TextTemplate)

PromptMessageRole = _reflection.GeneratedProtocolMessageType('PromptMessageRole', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTMESSAGEROLE,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptMessageRole)
  })
_sym_db.RegisterMessage(PromptMessageRole)

HumanPromptMessageRole = _reflection.GeneratedProtocolMessageType('HumanPromptMessageRole', (_message.Message,), {
  'DESCRIPTOR' : _HUMANPROMPTMESSAGEROLE,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.HumanPromptMessageRole)
  })
_sym_db.RegisterMessage(HumanPromptMessageRole)

SystemPromptMessageRole = _reflection.GeneratedProtocolMessageType('SystemPromptMessageRole', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMPROMPTMESSAGEROLE,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.SystemPromptMessageRole)
  })
_sym_db.RegisterMessage(SystemPromptMessageRole)

AIPromptMessageRole = _reflection.GeneratedProtocolMessageType('AIPromptMessageRole', (_message.Message,), {
  'DESCRIPTOR' : _AIPROMPTMESSAGEROLE,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.AIPromptMessageRole)
  })
_sym_db.RegisterMessage(AIPromptMessageRole)

PromptModelDescriptor = _reflection.GeneratedProtocolMessageType('PromptModelDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTMODELDESCRIPTOR,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptModelDescriptor)
  })
_sym_db.RegisterMessage(PromptModelDescriptor)

PromptOpenAIProvider = _reflection.GeneratedProtocolMessageType('PromptOpenAIProvider', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTOPENAIPROVIDER,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptOpenAIProvider)
  })
_sym_db.RegisterMessage(PromptOpenAIProvider)

PromptMetadata = _reflection.GeneratedProtocolMessageType('PromptMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTMETADATA,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptMetadata)
  })
_sym_db.RegisterMessage(PromptMetadata)

PromptVersionMetadata = _reflection.GeneratedProtocolMessageType('PromptVersionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PROMPTVERSIONMETADATA,
  '__module__' : 'qwak.prompt.v1.prompt.prompt_pb2'
  # @@protoc_insertion_point(class_scope:qwak.prompt.v1.prompt.PromptVersionMetadata)
  })
_sym_db.RegisterMessage(PromptVersionMetadata)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.qwak.ai.prompt.api.v1.promptP\001'
  _PROMPT._serialized_start=143
  _PROMPT._serialized_end=362
  _PROMPTVERSION._serialized_start=364
  _PROMPTVERSION._serialized_end=483
  _PROMPTVERSIONDEFINITION._serialized_start=486
  _PROMPTVERSIONDEFINITION._serialized_end=671
  _PROMPTBRIEF._serialized_start=673
  _PROMPTBRIEF._serialized_end=767
  _PROMPTVERSIONBRIEF._serialized_start=770
  _PROMPTVERSIONBRIEF._serialized_end=922
  _MODELPROVIDERBRIEF._serialized_start=924
  _MODELPROVIDERBRIEF._serialized_end=980
  _PROMPTSPEC._serialized_start=982
  _PROMPTSPEC._serialized_end=1015
  _PROMPTVERSIONSPEC._serialized_start=1018
  _PROMPTVERSIONSPEC._serialized_end=1225
  _PROMPTTEMPLATE._serialized_start=1227
  _PROMPTTEMPLATE._serialized_end=1326
  _CHATPROMPTTEMPLATE._serialized_start=1328
  _CHATPROMPTTEMPLATE._serialized_end=1407
  _CHATMESSAGE._serialized_start=1410
  _CHATMESSAGE._serialized_end=1541
  _CHATMESSAGETEMPLATE._serialized_start=1543
  _CHATMESSAGETEMPLATE._serialized_end=1634
  _TEXTTEMPLATE._serialized_start=1636
  _TEXTTEMPLATE._serialized_end=1668
  _PROMPTMESSAGEROLE._serialized_start=1671
  _PROMPTMESSAGEROLE._serialized_end=1901
  _HUMANPROMPTMESSAGEROLE._serialized_start=1903
  _HUMANPROMPTMESSAGEROLE._serialized_end=1927
  _SYSTEMPROMPTMESSAGEROLE._serialized_start=1929
  _SYSTEMPROMPTMESSAGEROLE._serialized_end=1954
  _AIPROMPTMESSAGEROLE._serialized_start=1956
  _AIPROMPTMESSAGEROLE._serialized_end=1977
  _PROMPTMODELDESCRIPTOR._serialized_start=1979
  _PROMPTMODELDESCRIPTOR._serialized_end=2093
  _PROMPTOPENAIPROVIDER._serialized_start=2095
  _PROMPTOPENAIPROVIDER._serialized_end=2211
  _PROMPTMETADATA._serialized_start=2213
  _PROMPTMETADATA._serialized_end=2297
  _PROMPTVERSIONMETADATA._serialized_start=2299
  _PROMPTVERSIONMETADATA._serialized_end=2390
# @@protoc_insertion_point(module_scope)



import uuid
from typing import Dict

import grpc
from _qwak_proto.qwak.integration.integration_pb2 import Integration, IntegrationSpec
from _qwak_proto.qwak.integration.integration_service_pb2 import (
    CreateIntegrationRequest,
    CreateIntegrationResponse,
    DeleteIntegrationRequest,
    DeleteIntegrationResponse,
    GetIntegrationRequest,
    GetIntegrationResponse,
    ListIntegrationRequest,
    ListIntegrationsResponse,
)
from _qwak_proto.qwak.integration.integration_service_pb2_grpc import (
    IntegrationManagementServiceServicer,
)
from _qwak_proto.qwak.integration.open_a_i_integration_pb2 import (
    OpenAIApiKeySystemSecretDescriptor,
    OpenAIIntegration,
)


class IntegrationManagementServiceMock(IntegrationManagementServiceServicer):
    _integrations: Dict[str, Integration] = dict()

    def clear(self):
        self._integrations.clear()

    def CreateIntegration(self, request: CreateIntegrationRequest, context):
        """Create a new integration in account level"""
        spec: IntegrationSpec = request.integration_spec
        if spec.WhichOneof("spec") != "openai_integration_spec":
            context.set_code(grpc.StatusCode.UNIMPLEMENTED)
            context.set_details("Method not implemented!")
            raise NotImplementedError("Method not implemented!")

        integration_id: str = str(uuid.uuid4())
        integration_name: str = str(uuid.uuid4())
        secret_name: str = str(uuid.uuid4())
        api_key_secret_key: str = str(uuid.uuid4())

        integration = Integration(
            integration_id=integration_id,
            name=integration_name,
            openai_integration=OpenAIIntegration(
                openai_api_key_system_secret_descriptor=OpenAIApiKeySystemSecretDescriptor(
                    secret_name=secret_name, api_key_secret_key=api_key_secret_key
                )
            ),
        )
        self._integrations[integration_id] = integration
        return CreateIntegrationResponse(
            integration_id=integration_id, is_successful=True
        )

    def GetIntegration(self, request: GetIntegrationRequest, context):
        """Get integration by id"""
        return GetIntegrationResponse(
            integration=self._integrations[request.integration_id]
        )

    def ListIntegrations(self, request: ListIntegrationRequest, context):
        """List Integrations for account"""
        return ListIntegrationsResponse(integrations=self._integrations.values())

    def DeleteIntegration(self, request: DeleteIntegrationRequest, context):
        """Delete Integration by id"""
        if request.integration_id in self._integrations:
            del self._integrations[request.integration_id]
        return DeleteIntegrationResponse()



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SetSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the secret"""
    value: builtins.str
    """Value of the secret"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___SetSecretRequest = SetSecretRequest

class SetSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetSecretResponse = SetSecretResponse

class GetSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the secret"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___GetSecretRequest = GetSecretRequest

class GetSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the secret"""
    value: builtins.str
    """Value of the secret"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___GetSecretResponse = GetSecretResponse

class DeleteSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the secret"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteSecretRequest = DeleteSecretRequest

class DeleteSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteSecretResponse = DeleteSecretResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/kube_deployment_captain/traffic_mapping.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2qwak/kube_deployment_captain/traffic_mapping.proto\x12\x1cqwak.kube.deployment.captain\"\xd8\x01\n\x10VariationMapping\x12\'\n\x1fselected_variation_mapping_name\x18\x01 \x01(\t\x12\"\n\x1atraffic_request_timeout_ms\x18\x04 \x01(\x05\x12\x15\n\rdeployment_id\x18\x03 \x01(\t\x12P\n\x14traffic_mapping_spec\x18\x02 \x01(\x0b\x32\x30.qwak.kube.deployment.captain.TrafficMappingSpecH\x00\x42\x0e\n\x0cmapping_spec\";\n\x12TrafficMappingSpec\x12\x12\n\npercentage\x18\x01 \x01(\x05\x12\x11\n\tis_shadow\x18\x02 \x01(\x08\x42+\n\'com.qwak.ai.kube.deployment.captain.apiP\x01\x62\x06proto3')



_VARIATIONMAPPING = DESCRIPTOR.message_types_by_name['VariationMapping']
_TRAFFICMAPPINGSPEC = DESCRIPTOR.message_types_by_name['TrafficMappingSpec']
VariationMapping = _reflection.GeneratedProtocolMessageType('VariationMapping', (_message.Message,), {
  'DESCRIPTOR' : _VARIATIONMAPPING,
  '__module__' : 'qwak.kube_deployment_captain.traffic_mapping_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.VariationMapping)
  })
_sym_db.RegisterMessage(VariationMapping)

TrafficMappingSpec = _reflection.GeneratedProtocolMessageType('TrafficMappingSpec', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICMAPPINGSPEC,
  '__module__' : 'qwak.kube_deployment_captain.traffic_mapping_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.TrafficMappingSpec)
  })
_sym_db.RegisterMessage(TrafficMappingSpec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.kube.deployment.captain.apiP\001'
  _VARIATIONMAPPING._serialized_start=85
  _VARIATIONMAPPING._serialized_end=301
  _TRAFFICMAPPINGSPEC._serialized_start=303
  _TRAFFICMAPPINGSPEC._serialized_end=362
# @@protoc_insertion_point(module_scope)



import json

from qwak.exceptions import QwakHTTPException

from .json_output import JsonOutput


def df_to_json(result, output_orient: str):
    import pandas as pd

    if isinstance(result, pd.DataFrame):
        return result.to_json(orient=output_orient)

    if isinstance(result, pd.Series):
        return pd.DataFrame(result).to_json(orient=output_orient)
    return json.dumps(result)


class DataFrameOutput(JsonOutput):
    def __init__(self, output_orient: str = "records"):
        self.output_orient = output_orient

    def pack_user_func_return_value(
        self,
        return_result,
    ) -> str:
        try:
            return df_to_json(return_result, self.output_orient)
        except Exception as e:
            raise QwakHTTPException(message=str(e), status_code=500)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.features_operator.v1.features_operator_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BaseValidationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTO_DEFINITION_FIELD_NUMBER: builtins.int
    IMPORTS_FIELD_NUMBER: builtins.int
    NUMBER_OF_SAMPLES_FIELD_NUMBER: builtins.int
    proto_definition: builtins.str
    """Proto definition to execute on Livy"""
    imports: builtins.str
    """Imports needed for the proto definition"""
    number_of_samples: builtins.int
    """Number of samples to return from the data source"""
    def __init__(
        self,
        *,
        proto_definition: builtins.str = ...,
        imports: builtins.str = ...,
        number_of_samples: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["imports", b"imports", "number_of_samples", b"number_of_samples", "proto_definition", b"proto_definition"]) -> None: ...

global___BaseValidationRequest = BaseValidationRequest

class ValidateDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_FIELD_NUMBER: builtins.int
    @property
    def request(self) -> global___BaseValidationRequest:
        """Base request properties"""
    def __init__(
        self,
        *,
        request: global___BaseValidationRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["request", b"request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["request", b"request"]) -> None: ...

global___ValidateDataSourceRequest = ValidateDataSourceRequest

class ValidateFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_FIELD_NUMBER: builtins.int
    S3_UDF_ZIP_PATH_FIELD_NUMBER: builtins.int
    @property
    def request(self) -> global___BaseValidationRequest:
        """Base request properties"""
    s3_udf_zip_path: builtins.str
    """S3 UDF ZIP path"""
    def __init__(
        self,
        *,
        request: global___BaseValidationRequest | None = ...,
        s3_udf_zip_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["request", b"request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["request", b"request", "s3_udf_zip_path", b"s3_udf_zip_path"]) -> None: ...

global___ValidateFeatureSetRequest = ValidateFeatureSetRequest

class ValidationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_RESPONSE_FIELD_NUMBER: builtins.int
    FAILURE_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def success_response(self) -> qwak.features_operator.v1.features_operator_pb2.ValidationSuccessResponse: ...
    @property
    def failure_response(self) -> qwak.features_operator.v1.features_operator_pb2.ValidationFailureResponse: ...
    def __init__(
        self,
        *,
        success_response: qwak.features_operator.v1.features_operator_pb2.ValidationSuccessResponse | None = ...,
        failure_response: qwak.features_operator.v1.features_operator_pb2.ValidationFailureResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failure_response", b"failure_response", "success_response", b"success_response", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_response", b"failure_response", "success_response", b"success_response", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["success_response", "failure_response"] | None: ...

global___ValidationResponse = ValidationResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/builds_orchestrator_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2
from _qwak_proto.qwak.builds import build_url_pb2 as qwak_dot_builds_dot_build__url__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/builds/builds_orchestrator_service.proto\x12\x18qwak.builds.orchestrator\x1a\x17qwak/builds/build.proto\x1a\x1bqwak/builds/build_url.proto\"R\n\x11\x42uildModelRequest\x12=\n\nbuild_spec\x18\x01 \x01(\x0b\x32).qwak.builds.orchestrator.RemoteBuildSpec\"\x14\n\x12\x42uildModelResponse\"+\n\x17\x43\x61ncelBuildModelRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"\x1a\n\x18\x43\x61ncelBuildModelResponse\"*\n\x16\x43reateUploadURLRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"C\n\x17\x43reateUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\"h\n\"GetBuildVersioningUploadURLRequest\x12\x42\n\x06params\x18\x01 \x01(\x0b\x32\x32.qwak.builds.orchestrator.BuildVersioningUrlParams\"\xa7\x02\n#GetBuildVersioningUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12Q\n\x15\x61uthentication_detail\x18\x03 \x01(\x0b\x32..qwak.builds.orchestrator.AuthenticationDetailB\x02\x18\x01\x12[\n\x07headers\x18\x04 \x03(\x0b\x32J.qwak.builds.orchestrator.GetBuildVersioningUploadURLResponse.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x14\x41uthenticationDetail\x12Z\n\x1bjfrog_authentication_detail\x18\x01 \x01(\x0b\x32\x33.qwak.builds.orchestrator.JfrogAuthenticationDetailH\x00\x42\x12\n\x10integration_type\"<\n\x19JfrogAuthenticationDetail\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"j\n$GetBuildVersioningDownloadURLRequest\x12\x42\n\x06params\x18\x01 \x01(\x0b\x32\x32.qwak.builds.orchestrator.BuildVersioningUrlParams\"\xdf\x01\n%GetBuildVersioningDownloadURLResponse\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12\x11\n\tfile_size\x18\x02 \x01(\x03\x12]\n\x07headers\x18\x03 \x03(\x0b\x32L.qwak.builds.orchestrator.GetBuildVersioningDownloadURLResponse.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x1eListBuildVersioningTagsRequest\x12L\n\x15\x62uild_versioning_tags\x18\x01 \x01(\x0b\x32-.qwak.builds.orchestrator.BuildVersioningTags\"\x9c\x01\n\x1fListBuildVersioningTagsResponse\x12\x61\n build_versioning_tags_properties\x18\x01 \x03(\x0b\x32\x37.qwak.builds.orchestrator.BuildVersioningTagsProperties\x12\x16\n\x0eui_direct_link\x18\x02 \x01(\t\"\x95\x01\n\x16\x43reateDataTableRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12<\n\x05table\x18\x04 \x01(\x0b\x32-.qwak.builds.orchestrator.DataTableDefinition\x12\x0c\n\x04path\x18\x05 \x01(\t\"\x19\n\x17\x43reateDataTableResponse\"n\n\x1dGetBaseDockerImageNameRequest\x12M\n\x16\x62\x61se_docker_image_type\x18\x01 \x01(\x0e\x32-.qwak.builds.orchestrator.BaseDockerImageType\"@\n\x1eGetBaseDockerImageNameResponse\x12\x1e\n\x16\x62\x61se_docker_image_name\x18\x01 \x01(\t\"f\n\x17SaveArtifactPathRequest\x12K\n\x12\x61rtifact_path_spec\x18\x01 \x01(\x0b\x32/.qwak.builds.orchestrator.BuildArtifactPathSpec\"\x1a\n\x18SaveArtifactPathResponse\"-\n\x19ListBuildArtifactsRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"X\n\x1aListBuildArtifactsResponse\x12:\n\tartifacts\x18\x01 \x03(\x0b\x32\'.qwak.builds.orchestrator.BuildArtifact2\xcf\n\n\x19\x42uildsOrchestratorService\x12g\n\nBuildModel\x12+.qwak.builds.orchestrator.BuildModelRequest\x1a,.qwak.builds.orchestrator.BuildModelResponse\x12y\n\x10\x43\x61ncelBuildModel\x12\x31.qwak.builds.orchestrator.CancelBuildModelRequest\x1a\x32.qwak.builds.orchestrator.CancelBuildModelResponse\x12{\n\x0f\x43reateUploadURL\x12\x30.qwak.builds.orchestrator.CreateUploadURLRequest\x1a\x31.qwak.builds.orchestrator.CreateUploadURLResponse\"\x03\x88\x02\x01\x12\x9a\x01\n\x1bGetBuildVersioningUploadURL\x12<.qwak.builds.orchestrator.GetBuildVersioningUploadURLRequest\x1a=.qwak.builds.orchestrator.GetBuildVersioningUploadURLResponse\x12\xa0\x01\n\x1dGetBuildVersioningDownloadURL\x12>.qwak.builds.orchestrator.GetBuildVersioningDownloadURLRequest\x1a?.qwak.builds.orchestrator.GetBuildVersioningDownloadURLResponse\x12\x8e\x01\n\x17ListBuildVersioningTags\x12\x38.qwak.builds.orchestrator.ListBuildVersioningTagsRequest\x1a\x39.qwak.builds.orchestrator.ListBuildVersioningTagsResponse\x12v\n\x0f\x43reateDataTable\x12\x30.qwak.builds.orchestrator.CreateDataTableRequest\x1a\x31.qwak.builds.orchestrator.CreateDataTableResponse\x12\x8b\x01\n\x16GetBaseDockerImageName\x12\x37.qwak.builds.orchestrator.GetBaseDockerImageNameRequest\x1a\x38.qwak.builds.orchestrator.GetBaseDockerImageNameResponse\x12y\n\x10SaveArtifactPath\x12\x31.qwak.builds.orchestrator.SaveArtifactPathRequest\x1a\x32.qwak.builds.orchestrator.SaveArtifactPathResponse\x12\x7f\n\x12ListBuildArtifacts\x12\x33.qwak.builds.orchestrator.ListBuildArtifactsRequest\x1a\x34.qwak.builds.orchestrator.ListBuildArtifactsResponseB\'\n#com.qwak.ai.builds.orchestrator.apiP\x01\x62\x06proto3')



_BUILDMODELREQUEST = DESCRIPTOR.message_types_by_name['BuildModelRequest']
_BUILDMODELRESPONSE = DESCRIPTOR.message_types_by_name['BuildModelResponse']
_CANCELBUILDMODELREQUEST = DESCRIPTOR.message_types_by_name['CancelBuildModelRequest']
_CANCELBUILDMODELRESPONSE = DESCRIPTOR.message_types_by_name['CancelBuildModelResponse']
_CREATEUPLOADURLREQUEST = DESCRIPTOR.message_types_by_name['CreateUploadURLRequest']
_CREATEUPLOADURLRESPONSE = DESCRIPTOR.message_types_by_name['CreateUploadURLResponse']
_GETBUILDVERSIONINGUPLOADURLREQUEST = DESCRIPTOR.message_types_by_name['GetBuildVersioningUploadURLRequest']
_GETBUILDVERSIONINGUPLOADURLRESPONSE = DESCRIPTOR.message_types_by_name['GetBuildVersioningUploadURLResponse']
_GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY = _GETBUILDVERSIONINGUPLOADURLRESPONSE.nested_types_by_name['HeadersEntry']
_AUTHENTICATIONDETAIL = DESCRIPTOR.message_types_by_name['AuthenticationDetail']
_JFROGAUTHENTICATIONDETAIL = DESCRIPTOR.message_types_by_name['JfrogAuthenticationDetail']
_GETBUILDVERSIONINGDOWNLOADURLREQUEST = DESCRIPTOR.message_types_by_name['GetBuildVersioningDownloadURLRequest']
_GETBUILDVERSIONINGDOWNLOADURLRESPONSE = DESCRIPTOR.message_types_by_name['GetBuildVersioningDownloadURLResponse']
_GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY = _GETBUILDVERSIONINGDOWNLOADURLRESPONSE.nested_types_by_name['HeadersEntry']
_LISTBUILDVERSIONINGTAGSREQUEST = DESCRIPTOR.message_types_by_name['ListBuildVersioningTagsRequest']
_LISTBUILDVERSIONINGTAGSRESPONSE = DESCRIPTOR.message_types_by_name['ListBuildVersioningTagsResponse']
_CREATEDATATABLEREQUEST = DESCRIPTOR.message_types_by_name['CreateDataTableRequest']
_CREATEDATATABLERESPONSE = DESCRIPTOR.message_types_by_name['CreateDataTableResponse']
_GETBASEDOCKERIMAGENAMEREQUEST = DESCRIPTOR.message_types_by_name['GetBaseDockerImageNameRequest']
_GETBASEDOCKERIMAGENAMERESPONSE = DESCRIPTOR.message_types_by_name['GetBaseDockerImageNameResponse']
_SAVEARTIFACTPATHREQUEST = DESCRIPTOR.message_types_by_name['SaveArtifactPathRequest']
_SAVEARTIFACTPATHRESPONSE = DESCRIPTOR.message_types_by_name['SaveArtifactPathResponse']
_LISTBUILDARTIFACTSREQUEST = DESCRIPTOR.message_types_by_name['ListBuildArtifactsRequest']
_LISTBUILDARTIFACTSRESPONSE = DESCRIPTOR.message_types_by_name['ListBuildArtifactsResponse']
BuildModelRequest = _reflection.GeneratedProtocolMessageType('BuildModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _BUILDMODELREQUEST,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildModelRequest)
  })
_sym_db.RegisterMessage(BuildModelRequest)

BuildModelResponse = _reflection.GeneratedProtocolMessageType('BuildModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _BUILDMODELRESPONSE,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildModelResponse)
  })
_sym_db.RegisterMessage(BuildModelResponse)

CancelBuildModelRequest = _reflection.GeneratedProtocolMessageType('CancelBuildModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELBUILDMODELREQUEST,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CancelBuildModelRequest)
  })
_sym_db.RegisterMessage(CancelBuildModelRequest)

CancelBuildModelResponse = _reflection.GeneratedProtocolMessageType('CancelBuildModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELBUILDMODELRESPONSE,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CancelBuildModelResponse)
  })
_sym_db.RegisterMessage(CancelBuildModelResponse)

CreateUploadURLRequest = _reflection.GeneratedProtocolMessageType('CreateUploadURLRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUPLOADURLREQUEST,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CreateUploadURLRequest)
  })
_sym_db.RegisterMessage(CreateUploadURLRequest)

CreateUploadURLResponse = _reflection.GeneratedProtocolMessageType('CreateUploadURLResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUPLOADURLRESPONSE,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CreateUploadURLResponse)
  })
_sym_db.RegisterMessage(CreateUploadURLResponse)

GetBuildVersioningUploadURLRequest = _reflection.GeneratedProtocolMessageType('GetBuildVersioningUploadURLRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDVERSIONINGUPLOADURLREQUEST,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.GetBuildVersioningUploadURLRequest)
  })
_sym_db.RegisterMessage(GetBuildVersioningUploadURLRequest)

GetBuildVersioningUploadURLResponse = _reflection.GeneratedProtocolMessageType('GetBuildVersioningUploadURLResponse', (_message.Message,), {

  'HeadersEntry' : _reflection.GeneratedProtocolMessageType('HeadersEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY,
    '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
    # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.GetBuildVersioningUploadURLResponse.HeadersEntry)
    })
  ,
  'DESCRIPTOR' : _GETBUILDVERSIONINGUPLOADURLRESPONSE,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.GetBuildVersioningUploadURLResponse)
  })
_sym_db.RegisterMessage(GetBuildVersioningUploadURLResponse)
_sym_db.RegisterMessage(GetBuildVersioningUploadURLResponse.HeadersEntry)

AuthenticationDetail = _reflection.GeneratedProtocolMessageType('AuthenticationDetail', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATIONDETAIL,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.AuthenticationDetail)
  })
_sym_db.RegisterMessage(AuthenticationDetail)

JfrogAuthenticationDetail = _reflection.GeneratedProtocolMessageType('JfrogAuthenticationDetail', (_message.Message,), {
  'DESCRIPTOR' : _JFROGAUTHENTICATIONDETAIL,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.JfrogAuthenticationDetail)
  })
_sym_db.RegisterMessage(JfrogAuthenticationDetail)

GetBuildVersioningDownloadURLRequest = _reflection.GeneratedProtocolMessageType('GetBuildVersioningDownloadURLRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDVERSIONINGDOWNLOADURLREQUEST,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.GetBuildVersioningDownloadURLRequest)
  })
_sym_db.RegisterMessage(GetBuildVersioningDownloadURLRequest)

GetBuildVersioningDownloadURLResponse = _reflection.GeneratedProtocolMessageType('GetBuildVersioningDownloadURLResponse', (_message.Message,), {

  'HeadersEntry' : _reflection.GeneratedProtocolMessageType('HeadersEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY,
    '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
    # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.GetBuildVersioningDownloadURLResponse.HeadersEntry)
    })
  ,
  'DESCRIPTOR' : _GETBUILDVERSIONINGDOWNLOADURLRESPONSE,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.GetBuildVersioningDownloadURLResponse)
  })
_sym_db.RegisterMessage(GetBuildVersioningDownloadURLResponse)
_sym_db.RegisterMessage(GetBuildVersioningDownloadURLResponse.HeadersEntry)

ListBuildVersioningTagsRequest = _reflection.GeneratedProtocolMessageType('ListBuildVersioningTagsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUILDVERSIONINGTAGSREQUEST,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.ListBuildVersioningTagsRequest)
  })
_sym_db.RegisterMessage(ListBuildVersioningTagsRequest)

ListBuildVersioningTagsResponse = _reflection.GeneratedProtocolMessageType('ListBuildVersioningTagsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUILDVERSIONINGTAGSRESPONSE,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.ListBuildVersioningTagsResponse)
  })
_sym_db.RegisterMessage(ListBuildVersioningTagsResponse)

CreateDataTableRequest = _reflection.GeneratedProtocolMessageType('CreateDataTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATATABLEREQUEST,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CreateDataTableRequest)
  })
_sym_db.RegisterMessage(CreateDataTableRequest)

CreateDataTableResponse = _reflection.GeneratedProtocolMessageType('CreateDataTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATATABLERESPONSE,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CreateDataTableResponse)
  })
_sym_db.RegisterMessage(CreateDataTableResponse)

GetBaseDockerImageNameRequest = _reflection.GeneratedProtocolMessageType('GetBaseDockerImageNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBASEDOCKERIMAGENAMEREQUEST,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.GetBaseDockerImageNameRequest)
  })
_sym_db.RegisterMessage(GetBaseDockerImageNameRequest)

GetBaseDockerImageNameResponse = _reflection.GeneratedProtocolMessageType('GetBaseDockerImageNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBASEDOCKERIMAGENAMERESPONSE,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.GetBaseDockerImageNameResponse)
  })
_sym_db.RegisterMessage(GetBaseDockerImageNameResponse)

SaveArtifactPathRequest = _reflection.GeneratedProtocolMessageType('SaveArtifactPathRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVEARTIFACTPATHREQUEST,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.SaveArtifactPathRequest)
  })
_sym_db.RegisterMessage(SaveArtifactPathRequest)

SaveArtifactPathResponse = _reflection.GeneratedProtocolMessageType('SaveArtifactPathResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVEARTIFACTPATHRESPONSE,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.SaveArtifactPathResponse)
  })
_sym_db.RegisterMessage(SaveArtifactPathResponse)

ListBuildArtifactsRequest = _reflection.GeneratedProtocolMessageType('ListBuildArtifactsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUILDARTIFACTSREQUEST,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.ListBuildArtifactsRequest)
  })
_sym_db.RegisterMessage(ListBuildArtifactsRequest)

ListBuildArtifactsResponse = _reflection.GeneratedProtocolMessageType('ListBuildArtifactsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUILDARTIFACTSRESPONSE,
  '__module__' : 'qwak.builds.builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.ListBuildArtifactsResponse)
  })
_sym_db.RegisterMessage(ListBuildArtifactsResponse)

_BUILDSORCHESTRATORSERVICE = DESCRIPTOR.services_by_name['BuildsOrchestratorService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.builds.orchestrator.apiP\001'
  _GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY._options = None
  _GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _GETBUILDVERSIONINGUPLOADURLRESPONSE.fields_by_name['authentication_detail']._options = None
  _GETBUILDVERSIONINGUPLOADURLRESPONSE.fields_by_name['authentication_detail']._serialized_options = b'\030\001'
  _GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY._options = None
  _GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _BUILDSORCHESTRATORSERVICE.methods_by_name['CreateUploadURL']._options = None
  _BUILDSORCHESTRATORSERVICE.methods_by_name['CreateUploadURL']._serialized_options = b'\210\002\001'
  _BUILDMODELREQUEST._serialized_start=129
  _BUILDMODELREQUEST._serialized_end=211
  _BUILDMODELRESPONSE._serialized_start=213
  _BUILDMODELRESPONSE._serialized_end=233
  _CANCELBUILDMODELREQUEST._serialized_start=235
  _CANCELBUILDMODELREQUEST._serialized_end=278
  _CANCELBUILDMODELRESPONSE._serialized_start=280
  _CANCELBUILDMODELRESPONSE._serialized_end=306
  _CREATEUPLOADURLREQUEST._serialized_start=308
  _CREATEUPLOADURLREQUEST._serialized_end=350
  _CREATEUPLOADURLRESPONSE._serialized_start=352
  _CREATEUPLOADURLRESPONSE._serialized_end=419
  _GETBUILDVERSIONINGUPLOADURLREQUEST._serialized_start=421
  _GETBUILDVERSIONINGUPLOADURLREQUEST._serialized_end=525
  _GETBUILDVERSIONINGUPLOADURLRESPONSE._serialized_start=528
  _GETBUILDVERSIONINGUPLOADURLRESPONSE._serialized_end=823
  _GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY._serialized_start=777
  _GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY._serialized_end=823
  _AUTHENTICATIONDETAIL._serialized_start=826
  _AUTHENTICATIONDETAIL._serialized_end=960
  _JFROGAUTHENTICATIONDETAIL._serialized_start=962
  _JFROGAUTHENTICATIONDETAIL._serialized_end=1022
  _GETBUILDVERSIONINGDOWNLOADURLREQUEST._serialized_start=1024
  _GETBUILDVERSIONINGDOWNLOADURLREQUEST._serialized_end=1130
  _GETBUILDVERSIONINGDOWNLOADURLRESPONSE._serialized_start=1133
  _GETBUILDVERSIONINGDOWNLOADURLRESPONSE._serialized_end=1356
  _GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY._serialized_start=777
  _GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY._serialized_end=823
  _LISTBUILDVERSIONINGTAGSREQUEST._serialized_start=1358
  _LISTBUILDVERSIONINGTAGSREQUEST._serialized_end=1468
  _LISTBUILDVERSIONINGTAGSRESPONSE._serialized_start=1471
  _LISTBUILDVERSIONINGTAGSRESPONSE._serialized_end=1627
  _CREATEDATATABLEREQUEST._serialized_start=1630
  _CREATEDATATABLEREQUEST._serialized_end=1779
  _CREATEDATATABLERESPONSE._serialized_start=1781
  _CREATEDATATABLERESPONSE._serialized_end=1806
  _GETBASEDOCKERIMAGENAMEREQUEST._serialized_start=1808
  _GETBASEDOCKERIMAGENAMEREQUEST._serialized_end=1918
  _GETBASEDOCKERIMAGENAMERESPONSE._serialized_start=1920
  _GETBASEDOCKERIMAGENAMERESPONSE._serialized_end=1984
  _SAVEARTIFACTPATHREQUEST._serialized_start=1986
  _SAVEARTIFACTPATHREQUEST._serialized_end=2088
  _SAVEARTIFACTPATHRESPONSE._serialized_start=2090
  _SAVEARTIFACTPATHRESPONSE._serialized_end=2116
  _LISTBUILDARTIFACTSREQUEST._serialized_start=2118
  _LISTBUILDARTIFACTSREQUEST._serialized_end=2163
  _LISTBUILDARTIFACTSRESPONSE._serialized_start=2165
  _LISTBUILDARTIFACTSRESPONSE._serialized_end=2253
  _BUILDSORCHESTRATORSERVICE._serialized_start=2256
  _BUILDSORCHESTRATORSERVICE._serialized_end=3615
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.auto_scaling.v1.auto_scaling_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AttachAutoScalingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    VARIATION_NAME_FIELD_NUMBER: builtins.int
    AUTO_SCALING_CONFIG_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The ID of the model to scale"""
    variation_name: builtins.str
    """Deployment variation name"""
    @property
    def auto_scaling_config(self) -> qwak.auto_scaling.v1.auto_scaling_pb2.AutoScalingConfig:
        """Auto scaling"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        variation_name: builtins.str = ...,
        auto_scaling_config: qwak.auto_scaling.v1.auto_scaling_pb2.AutoScalingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_scaling_config", b"auto_scaling_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_scaling_config", b"auto_scaling_config", "model_id", b"model_id", "variation_name", b"variation_name"]) -> None: ...

global___AttachAutoScalingRequest = AttachAutoScalingRequest

class AttachAutoScalingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_SCALING_ID_FIELD_NUMBER: builtins.int
    auto_scaling_id: builtins.str
    def __init__(
        self,
        *,
        auto_scaling_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_scaling_id", b"auto_scaling_id"]) -> None: ...

global___AttachAutoScalingResponse = AttachAutoScalingResponse
